==> mudlet_3.2.0.orig.tar.xz: mudlet-3.2.0/README.md <==
# Mudlet

[![Build Status](https://travis-ci.org/Mudlet/Mudlet.svg?branch=development)](https://travis-ci.org/Mudlet/Mudlet) [![GitHub stars](https://img.shields.io/github/stars/Mudlet/Mudlet.svg)](https://github.com/Mudlet/Mudlet/stargazers)
[![Gitter](https://badges.gitter.im/Join%20Chat.svg)](https://gitter.im/Mudlet/Mudlet?utm_source=badge&utm_medium=badge&utm_campaign=pr-badge&utm_content=badge)

Mudlet is a quality MUD client, designed to take mudding to a new level.

It’s a new breed of a client on the MUD scene – with an intuitive user interface, a specially designed scripting framework, and a very fast text display. That, along with cross-platform capability and an open-source development model results in a very likable MUD client.

## Easy to use client

We’re big on usability, and as such, creating an easy to use client and interface is one of the defining goals of the project. This applies to both the power users and plain gamers – everyone will feel at home with Mudlet, without having to waste too much time figuring out how to do something. Comments on display improvement are always welcome, and we’ll continue refining the design to perfection continually.

## Designed for speed

Mudlet is designed to be very fast and efficient right from the start, and we’re building it to be so. It’s scripting engine is designed to scale to large systems without bogging down – and the text display is designed to handle thousands of lines under a second. All in all, we are very serious about Mudlet being quick – and take all chances to make it so.

## Powerful Scripting

Mudlet features a scripting framework using [Lua](https://www.lua.org/) – a small, fast and efficient scripting language. This allows Mudlet to leverage the existing community and large ecosystem of existing packages for Lua without the many drawbacks of creating a Mudlet specific scripting language. Best of all, the Lua API is seamlessly integrated in Mudlet and shared by all aliases, triggers, scripts, keybindings, buttons and other Mudlet components.

## Cross-Platform love

We believe in making Mudlet available to people on all major platforms, and we work on keeping cross-platform compatibility right from start. Mudlet will be available on Linux (both 32bit and 64bit), Windows, and Macs.

## And many other things…

Such as package creation / sharing, 3D mapper are in our plans. You’re welcome to suggest ideas, too!

==> mudlet_3.7.1.orig.tar.xz: mudlet-3.7.1/README.md <==

# Mudlet

[![AppVeyor Build status](https://ci.appveyor.com/api/projects/status/31fqq844br6g6i40/branch/development?svg=true)](https://ci.appveyor.com/project/Mudlet/mudlet/branch/development) [![GitHub Build Status](https://travis-ci.org/Mudlet/Mudlet.svg?branch=development)](https://travis-ci.org/Mudlet/Mudlet) [![GitHub stars](https://img.shields.io/github/stars/Mudlet/Mudlet.svg)](https://github.com/Mudlet/Mudlet/stargazers) [![Gitter](https://badges.gitter.im/Join%20Chat.svg)](https://gitter.im/Mudlet/Mudlet?utm_source=badge&utm_medium=badge&utm_campaign=pr-badge&utm_content=badge) [![Discord](https://img.shields.io/badge/discord-join%20chat-7289DA.svg)](https://discord.gg/kuYvMQ9)

Mudlet is a quality MUD client, designed to take mudding to a new level.

It’s a new breed of a client on the MUD scene – with an intuitive user interface, a specially designed scripting framework, and a very fast text display. That, along with cross-platform capability and an open-source development model results in a very likable MUD client.

## Easy to use client

We’re big on usability, and as such, creating an easy to use client and interface is one of the defining goals of the project. This applies to both the power users and plain gamers – everyone will feel at home with Mudlet, without having to waste too much time figuring out how to do something. Comments on display improvement are always welcome, and we’ll continue refining the design to perfection continually.

## Designed for speed

Mudlet is designed to be very fast and efficient right from the start, and we’re building it to be so. It’s scripting engine is designed to scale to large systems without bogging down – and the text display is designed to handle thousands of lines under a second. All in all, we are very serious about Mudlet being quick – and take all chances to make it so.

## Powerful Scripting

Mudlet features a scripting framework using [Lua](https://www.lua.org/) – a small, fast and efficient scripting language. This allows Mudlet to leverage the existing community and large ecosystem of existing packages for Lua without the many drawbacks of creating a Mudlet specific scripting language. Best of all, the Lua API is seamlessly integrated in Mudlet and shared by all aliases, triggers, scripts, keybindings, buttons and other Mudlet components.

## Cross-Platform love

We believe in making Mudlet available to people on all major platforms, and we work on keeping cross-platform compatibility right from start. Mudlet will be available on Linux (both 32bit and 64bit), Windows, and Macs.

## And many other things…

Such as package creation / sharing, 3D mapper are in our plans. You’re welcome to suggest ideas, too!

## Compiling

Please see the [compiling page](https://wiki.mudlet.org/w/Compiling_Mudlet) on how to compile Mudlet on all platforms: Windows, macOS, and Linux OS's.
